@@ -1,4 +1,12 @@
+use strict;
+use warnings;
+
 package CPAN::Mini::Webserver::Index;
+
+# ABSTRACT: search term index for a CPAN::Mini web server
+
+our $VERSION = '0.56'; # VERSION
+
 use Moose;
 use List::MoreUtils qw(uniq);
 use Search::QueryParser;
@@ -147,3 +155,46 @@ sub search_word {
 }
 
 1;
+
+
+
+=pod
+
+=head1 NAME
+
+CPAN::Mini::Webserver::Index - search term index for a CPAN::Mini web server
+
+=head1 VERSION
+
+version 0.56
+
+=head1 DESCRIPTION
+
+This module indexes words for the search feature in CPAN::Mini::Webserver.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Leon Brocard <acme@astray.com>
+
+=item *
+
+Christian Walde <walde.christian@googlemail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Christian Walde.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
